@@ -110,6 +110,8 @@ $stream must be defined. Otherwise an exception is thrown.
 
 $nmemb * $size must be less than or equal to the length of $ptr - $ptr_offset. Otherwise an exception is thrown.
 
+If the return value is less than $nmemb and C<ferror(stream)> is non-zero, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
 =head2 feof
 
 C<static method feof : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
@@ -150,6 +152,8 @@ Exceptions:
 
 $stream must be defined. Otherwise an exception is thrown.
 
+If the return value is C<EOF> and C<ferror(stream)> is non-zero, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
 =head2 ungetc
 
 C<static method ungetc : int ($c : int, $stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
@@ -160,7 +164,7 @@ Exceptions:
 
 $stream must be defined. Otherwise an exception is thrown.
 
-If the ungetc function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+If the return value is C<EOF> and C<ferror(stream)> is non-zero, an exception is thrown.
 
 =head2 fgets
 
@@ -196,6 +200,8 @@ $stream must be defined. Otherwise an exception is thrown.
 
 $nmemb * $size must be less than or equal to the length of $ptr - $ptr_offset. Otherwise an exception is thrown.
 
+If the return value is less than $nmemb and C<ferror(stream)> is non-zero, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
 =head2 fclose
 
 C<static method fclose : int ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
@@ -314,381 +320,430 @@ $mode is C<_IOLBF>.
 
 $size is C<BUFSIZ>.
 
-=head2 fsync
-
-C<static method fsync : int ($fd : int);>
-
-fsync() transfers ("flushes") all modified in-core data of (i.e., modified buffer cache pages for) the file referred to by the file descriptor fd to the disk device (or other permanent storage device) so that all changed information can be retrieved even after the system crashed or was rebooted.
-
-See L<fsync(2) - Linux man page|https://linux.die.net/man/2/fsync> in Linux.
-
-Exceptions:
-
-=head2 flock
-
-C<static method flock : int ($fd : int, $operation : int);>
-
-Apply or remove an advisory lock on the open file specified by fd. The argument operation is one of the following:
-
-See the L<flock|https://linux.die.net/man/2/flock> function in Linux.
-
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the operation.
-
-Exceptions:
-
-=head2 mkdir
-
-C<static method mkdir : int ($path : string, $mode : int);>
-
-mkdir() attempts to create a directory named pathname.
-
-See the L<mkdir|https://linux.die.net/man/2/mkdir> function in Linux.
-
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
-
-Exceptions:
-
-=head2 umask
-
-C<static method umask : int ($mode : int);>
-
-umask() sets the calling process's file mode creation mask (umask) to mask & 0777 (i.e., only the file permission bits of mask are used), and returns the previous value of the mask.
-
-See the L<umask|https://linux.die.net/man/2/umask> function in Linux.
-
-Exceptions:
-
-=head2 rmdir
-
-C<static method rmdir : int ($path : string);>
-
-rmdir() deletes a directory, which must be empty.
-
-See the L<rmdir|https://linux.die.net/man/2/rmdir> function in Linux.
-
-Exceptions:
-
-=head2 unlink
-
-C<static method unlink : int ($pathname : string);>
-
-unlink() deletes a name from the file system. If that name was the last link to a file and no processes have the file open the file is deleted and the space it was using is made available for reuse.
-
-See the L<unlink|https://linux.die.net/man/2/unlink> function in Linux.
-
-Exceptions:
-
-=head2 rename
-
-C<static method rename : int ($oldpath : string, $newpath : string);>
-
-rename() renames a file, moving it between directories if required. Any other hard links to the file (as created using link(2)) are unaffected. Open file descriptors for oldpath are also unaffected.
-
-See the L<rename|https://linux.die.net/man/2/rename> function in Linux.
-
-Exceptions:
-
-=head2 getcwd
-
-C<static method getcwd : mutable string ($buf : mutable string, $size : int);>
-
-The getcwd() function copies an absolute pathname of the current working directory to the array pointed to by buf, which is of length size.
-
-See the L<getcwd|https://linux.die.net/man/2/getcwd> function in Linux.
-
-Exceptions:
-
-=head2 _getdcwd
-
-C<static method _getdcwd : mutable string ($drive : int, $buffer : mutable string, $maxlen : int);>
-
-Gets the full path of the current working directory on the specified drive.
-
-See the L<_getdcwd|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/getdcwd-wgetdcwd?view=msvc-170> function in the case of Windows.
-
-Exceptions:
-
-=head2 realpath
-
-C<static method realpath : mutable string ($path : string, $resolved_path : mutable string);>
-
-realpath() expands all symbolic links and resolves references to /./, /../ and extra '/' characters in the null-terminated string named by path to produce a canonicalized absolute pathname. The resulting pathname is stored as a null-terminated string, up to a maximum of PATH_MAX bytes, in the buf pointed to by resolved_path. The resulting path will have no symbolic link, /./ or /../ components.
-
-See the L<realpath|https://linux.die.net/man/3/realpath> function in Linux.
-
-Exceptions:
-
-=head2 _fullpath
-
-C<native static method _fullpath : mutable string ($absPath : mutable string, $relPath : string, $maxLength : int);>
-
-Creates an absolute or full path name for the specified relative path name.
-
-See the L<_fullpath|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/fullpath-wfullpath?view=msvc-170> function in the case of Windows.
-
-Exceptions:
-
-=head2 chdir
-
-C<static method chdir : int ($path : string);>
-
-chdir() changes the current working directory of the calling process to the directory specified in path.
-
-See the L<chdir|https://linux.die.net/man/2/chdir> function in Linux.
-
-Exceptions:
-
-=head2 chmod
-
-C<static method chmod : int ($path : string, $mode :int);>
-
-chmod() changes the permissions of the file specified whose pathname is given in path, which is dereferenced if it is a symbolic link.
-
-See the L<chmod|https://linux.die.net/man/2/chmod> function in Linux.
-
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
-
-Exceptions:
-
-=head2 chown
-
-C<static method chown : int ($path : string, $owner : int, $group : int);>
-
-chown() changes the ownership of the file specified by path, which is dereferenced if it is a symbolic link.
-
-See the L<chown|https://linux.die.net/man/2/chown> function in Linux.
-
-Exceptions:
-
-=head2 truncate
-
-C<static method truncate : int ($path : string, $length : long);>
-
-The truncate() and ftruncate() functions cause the regular file named by path or referenced by fd to be truncated to a size of precisely length bytes.
-
-See the L<truncate|https://linux.die.net/man/2/truncate> function in Linux.
-
-Exceptions:
-
-=head2 symlink
-
-C<static method symlink : int ($oldpath : string, $newpath : string);>
-
-symlink() creates a symbolic link named newpath which contains the string oldpath.
-
-See the L<symlink|https://linux.die.net/man/2/symlink> function in Linux.
-
-Exceptions:
-
-=head2 readlink
-
-C<static method readlink : int ($path : string, $buf : mutable string, $bufsiz : int);>
-
-readlink() places the contents of the symbolic link path in the buf buf, which has size bufsiz. readlink() does not append a null byte to buf. It will truncate the contents (to a length of bufsiz characters), in case the buf is too small to hold all of the contents.
-
-See the L<readlink|https://linux.die.net/man/2/readlink> function in Linux.
-
-Exceptions:
-
-=head2 get_readlink_buffer_size
-
-C<native static method get_readlink_buffer_size : int ($path : string);>
-
-Gets the L</"readlink"> needed buffer size.
-
-Exceptions:
-
-=head2 opendir
-
-C<static method opendir : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> ($dir : string);>
-
-The opendir() function opens a directory stream corresponding to the directory name, and returns a pointer to the directory stream. The stream is positioned at the first entry in the directory.
-
-See the L<opendir|https://linux.die.net/man/3/opendir> function in Linux.
-
-The return value is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
-
-Exceptions:
-
-=head2 closedir
-
-C<static method closedir : int ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
-
-The closedir() function closes the directory stream associated with dirp. A successful call to closedir() also closes the underlying file descriptor associated with dirp. The directory stream descriptor dirp is not available after this call.
-
-See the L<closedir|https://linux.die.net/man/3/closedir> function in Linux.
-
-The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
-
-Exceptions:
-
-=head2 readdir
-
-C<static method readdir : L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>); # Non-thead safe>
-
-The readdir() function returns a pointer to a dirent structure representing the next directory entry in the directory stream pointed to by dirp. It returns NULL on reaching the end of the directory stream or if an error occurred.
-
-See the L<readdir|https://linux.die.net/man/3/readdir> function in Linux.
-
-The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
-
-The return value is a L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> object.
-
-Exceptions:
-
-=head2 rewinddir
-
-C<static method rewinddir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
-
-The rewinddir() function resets the position of the directory stream dirp to the beginning of the directory.
-
-See the L<rewinddir|https://linux.die.net/man/3/rewinddir> function in Linux.
-
-The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
-
-Exceptions:
-
-=head2 telldir
-
-C<static method telldir : long ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
-
-The telldir() function returns the current location associated with the directory stream dirp.
-
-See the L<telldir|https://linux.die.net/man/3/telldir> function in Linux.
-
-The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
-
-Exceptions:
-
-=head2 seekdir
-
-C<static method seekdir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>, $offset : long);>
-
-The seekdir() function sets the location in the directory stream from which the next readdir(2) call will start. seekdir() should be used with an offset returned by telldir(3).
-See the L<seekdir|https://linux.die.net/man/3/seekdir> function in Linux.
-
-The directory stream is a L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> object.
-
-Exceptions:
-
-=head2 access
-
-C<static method access : int ($pathname : string, $mode : int);>
-
-access() checks whether the calling process can access the file pathname. If pathname is a symbolic link, it is dereferenced.
-
-See the L<access|https://linux.die.net/man/2/access> function in Linux.
-
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the mode.
-
-Exceptions:
-
-=head2 eaccess
-
-C<static method eaccess : int ($pathname : string, $mode : int);>
-
-eaccess() checks whether the calling process can eaccess the file pathname. If pathname is a symbolic link, it is dereferenced.
-
-See the L<eaccess|https://linux.die.net/man/3/eaccess> function in Linux.
-
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the $mode.
-
-Exceptions:
-
-=head2 faccessat
-
-  static method faccessat : int ($dirfd : int, $pathname : string, $mode : int, $flags : int);
-
-check user's permissions of a file relative to a directory file descriptor.
-
-See the L<faccessat|https://linux.die.net/man/2/faccessat> function in Linux.
-
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the $mode and $flag.
-
-Exceptions:
-
-=head2 fcntl
-
-C<static method fcntl : int ($fd : int, $command : int, $command_arg : object of Int|Sys::IO::Flock|object = undef);>
-
-fcntl() performs one of the operations described below on the open file descriptor fd. The operation is determined by cmd.
-
-See the L<lstat|https://linux.die.net/man/2/fcntl> function in Linux.
-
-The command argument can receive a L<Sys::IO::Flock|SPVM::Sys::IO::Flock> object.
-
-Exceptions:
-
-=head2 ftruncate
-
-C<static method ftruncate : int ($fd : int, $length : long);>
-
-The ftruncate() functions cause the regular file named by referenced by fd to be truncated to a size of precisely length bytes.
-
-See L<ftruncate(2) - Linux man page|https://linux.die.net/man/2/ftruncate> in Linux.
-
-Exceptions:
-
 =head2 open
 
 C<static method open : int ($path : string, $flags : int, $mode : int = 0);>
 
-Given a pathname for a file, open() returns a file descriptor, a small, nonnegative integer for use in subsequent system calls (read(2), write(2), lseek(2), fcntl(2), etc.). The file descriptor returned by a successful call will be the lowest-numbered file descriptor not currently open for the process.
+Calls the L<open|https://linux.die.net/man/2/open> function and returns its return value.
 
-See the L<open|https://linux.die.net/man/2/open> function in Linux.
-
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the flags and the mode.
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to the flags $flags and the mode $mode.
 
 Exceptions:
 
+$path must be defined. Otherwise an exception is thrown.
+
+If the open function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
 =head2 read
 
 C<static method read : int ($fd : int, $buf : mutable string, $count : int, $buf_offset : int = 0);>
 
-read() attempts to read up to count bytes from file descriptor fd into the buf starting at buf + buf_offset.
-
-See the L<read|https://linux.die.net/man/2/read> function in Linux.
+Calls the L<read|https://linux.die.net/man/2/read> function and returns its return value.
 
 Exceptions:
 
+$buf must be defined. Otherwise an exception is thrown.
+
+$count must be more than or equal to 0. Otherwise an exception is thrown.
+
+$count must be less than the length of $buf - $buf_offset. Otherwise an exception is thrown.
+
+If the read function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
 =head2 write
 
 C<static method write : int ($fd : int, $buf : string, $count : int, $buf_offset : int = 0);>
 
-write() writes up to count bytes from the buf pointed buf + buf_offset to the file referred to by the file descriptor fd.
-
-See the L<write|https://linux.die.net/man/2/write> function in Linux.
+Calls the L<write|https://linux.die.net/man/2/write> function and returns its return value.
 
 Exceptions:
 
+$buf must be defined. Otherwise an exception is thrown.
+
+$buf_offse must be greater than or equal to 0. Otherwise an exception is thrown.
+
+$count must be less than the length of $buf - $buf_offset. Otherwise an exception is thrown.
+
+If the write function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
 =head2 lseek
 
 C<static method lseek : long ($fd : int, $offset : long, $whence : int);>
 
-The lseek() function repositions the offset of the open file associated with the file descriptor fd to the argument offset according to the directive whence as follows:
+Calls the L<lseek|https://linux.die.net/man/2/lseek> function and returns its return value.
 
-See the L<lseek|https://linux.die.net/man/2/lseek> function in Linux.
-
-See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about the constant value for the whence.
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to $whence.
 
 Exceptions:
 
+$offset must be greater than or equal to 0. Otherwise an exception is thrown.
+
+If the lseek function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
 =head2 close
 
 C<static method close : int ($fd : int);>
 
-close() closes a file descriptor, so that it no longer refers to any file and may be reused. Any record locks (see fcntl(2)) held on the file it was associated with, and owned by the process, are removed (regardless of the file descriptor that was used to obtain the lock).
-
-See the L<close|https://linux.die.net/man/2/close> function in Linux.
+Calls the L<close|https://linux.die.net/man/2/close> function and returns its return value.
 
 Exceptions:
 
+If the close function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 fsync
+
+C<static method fsync : int ($fd : int);>
+
+Calls the L<fsync|https://linux.die.net/man/2/fsync> function and returns its return value.
+
+Exceptions:
+
+If the fsync function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 fcntl
+
+C<static method fcntl : int ($fd : int, $command : int, $command_arg : object of Int|SPVM::Sys::IO::Flock = undef);>
+
+Calls the L<fcntl|https://linux.die.net/man/2/fcntl> function and returns its return value.
+
+Exceptions:
+
+$command_arg must be an instance of the Int class or Sys::IO::Flock class.
+
+=head2 ftruncate
+
+C<static method ftruncate : int ($fd : int, $length : long);>
+
+Calls the L<ftruncate|https://linux.die.net/man/2/ftruncate> function and returns its return value.
+
+Exceptions:
+
+If the ftruncate function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 flock
+
+C<static method flock : int ($fd : int, $operation : int);>
+
+Calls the L<flock|https://linux.die.net/man/2/flock> function and returns its return value.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to the operation $operation.
+
+Exceptions:
+
+If the flock function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 access
+
+C<static method access : int ($pathname : string, $mode : int);>
+
+Calls the L<access|https://linux.die.net/man/2/access> function and returns its return value.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to the mode $mode.
+
+Exceptions:
+
+$pathname must be defined. Otherwise an exception is thrown.
+
+If the access function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 faccessat
+
+  static method faccessat : int ($dirfd : int, $pathname : string, $mode : int, $flags : int);
+
+Calls the L<faccessat|https://linux.die.net/man/2/faccessat> function and returns its return value.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to the mode $mode and the flag $flag.
+
+Exceptions:
+
+$pathname must be defined. Otherwise an exception is thrown.
+
+If the faccessat function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 eaccess
+
+C<static method eaccess : int ($pathname : string, $mode : int);>
+
+Calls the L</"faccessat"> method given the following $dirfd and $flag.
+
+$dirfd is C<AT_FDCWD>.
+
+$flag is C<AT_EACCESS>.
+
+=head2 truncate
+
+C<static method truncate : int ($path : string, $length : long);>
+
+Calls the L<truncate|https://linux.die.net/man/2/truncate> function and returns its return value.
+
+Exceptions:
+
+$path must be defined. Otherwise an exception is thrown.
+
+$length must be less than or equal to 0.
+
+If the truncate function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 mkdir
+
+C<static method mkdir : int ($path : string, $mode : int);>
+
+Windows:
+
+Calls the L<_mkdir|https://learn.microsoft.com/en-us/cpp/c-runtime-library/reference/mkdir-wmkdir?view=msvc-170> function and return its return value.
+
+OS other than Windows:
+
+Calls the L<mkdir|https://linux.die.net/man/2/mkdir> function and return its return value.
+
+Exceptions:
+
+If the mkdir(or _mkdir) function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 umask
+
+C<static method umask : int ($mode : int);>
+
+Calls the L<umask|https://linux.die.net/man/2/umask> function and return its return value.
+
+=head2 rmdir
+
+C<static method rmdir : int ($path : string);>
+
+Calls the L<rmdir|https://linux.die.net/man/2/rmdir> function and return its return value.
+
+Exceptions:
+
+$path must be defined. Otherwise an exception is thrown.
+
+If the rmdir function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 unlink
+
+C<static method unlink : int ($pathname : string);>
+
+Calls the L<unlink|https://linux.die.net/man/2/unlink> function and return its return value.
+
+Exceptions:
+
+$pathname must be defined. Otherwise an exception is thrown.
+
+If the unlink function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 rename
+
+C<static method rename : int ($oldpath : string, $newpath : string);>
+
+Calls the L<rename|https://linux.die.net/man/2/rename> function and return its return value.
+
+Exceptions:
+
+$oldpath must be defined. Otherwise an exception is thrown.
+
+$newpath must be defined. Otherwise an exception is thrown.
+
+If the rename function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 getcwd
+
+C<static method getcwd : mutable string ($buf : mutable string, $size : int);>
+
+Calls the L<getcwd|https://linux.die.net/man/2/getcwd> function and return its return value.
+
+Exceptions:
+
+$size must be greater than or equal to 0. Otherwise an exception is thrown.
+
+If $buf is defined, $size must be greater than or equal to 0. Otherwise an exception is thrown.
+
+If the getcwd function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 _getdcwd
+
+C<static method _getdcwd : mutable string ($drive : int, $buffer : mutable string, $maxlen : int);>
+
+Calls the L<_getdcwd|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/getdcwd-wgetdcwd?view=msvc-170> function and return its return value.
+
+Exceptions:
+
+$maxlen must be greater than 0. Otherwise an exception is thrown.
+
+$maxlen must be less than or equal to the lenght of $buffer. Otherwise an exception is thrown.
+
+If the _getdcwd function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 realpath
+
+C<static method realpath : mutable string ($path : string, $resolved_path : mutable string);>
+
+Calls the L<realpath|https://linux.die.net/man/3/realpath> function and return its return value.
+
+Exceptions:
+
+$path must be defined. Otherwise an exception is thrown.
+
+If the realpath function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 _fullpath
+
+C<native static method _fullpath : mutable string ($absPath : mutable string, $relPath : string, $maxLength : int);>
+
+Calls the L<_fullpath|https://docs.microsoft.com/en-us/cpp/c-runtime-library/reference/fullpath-wfullpath?view=msvc-170> function and return its return value.
+
+Exceptions:
+
+$relPath must be defined. Otherwise an exception is thrown.
+
+If the _fullpath function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 chdir
+
+C<static method chdir : int ($path : string);>
+
+Calls the L<chdir|https://linux.die.net/man/2/chdir> function and return its return value.
+
+Exceptions:
+
+$path must be defined. Otherwise an exception is thrown.
+
+If the chdir function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 chmod
+
+C<static method chmod : int ($path : string, $mode :int);>
+
+Calls the L<chmod|https://linux.die.net/man/2/chmod> function and return its return value.
+
+See L<Sys::IO::Constant|SPVM::Sys::IO::Constant> about constant values given to the mode $mode.
+
+Exceptions:
+
+$path must be defined. Otherwise an exception is thrown.
+
+If the chmod function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 chown
+
+C<static method chown : int ($path : string, $owner : int, $group : int);>
+
+Calls the L<chown|https://linux.die.net/man/2/chown> and return its return value.
+
+Exceptions:
+
+$path must be defined. Otherwise an exception is thrown.
+
+If the chown function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 symlink
+
+C<static method symlink : int ($oldpath : string, $newpath : string);>
+
+Calls the L<symlink|https://linux.die.net/man/2/symlink> function and return its return value.
+
+Exceptions:
+
+$oldpath must be defined. Otherwise an exception is thrown.
+
+$newpath must be defined. Otherwise an exception is thrown.
+
+If the symlink function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 readlink
+
+C<static method readlink : int ($path : string, $buf : mutable string, $bufsiz : int);>
+
+Calls the L<readlink|https://linux.die.net/man/2/readlink> function and return its return value.
+
+Exceptions:
+
+$path must be defined. Otherwise an exception is thrown.
+
+$buf must be defined. Otherwise an exception is thrown.
+
+$bufsiz must be greater than or equal to 0. Otherwise an exception is thrown.
+
+$bufsiz must be less than or equal to the length of $buf. Otherwise an exception is thrown.
+
+If the readlink function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 opendir
+
+C<static method opendir : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream> ($dir : string);>
+
+Calls the L<opendir|https://linux.die.net/man/3/opendir> function and return its return value.
+
+Exceptions:
+
+$dir must be defined. Otherwise an exception is thrown.
+
+If the opendir function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 closedir
+
+C<static method closedir : int ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
+
+Calls the L<closedir|https://linux.die.net/man/3/closedir> function and return its return value.
+
+Exceptions:
+
+$dirp must be defined. Otherwise an exception is thrown.
+
+If the closedir function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 readdir
+
+C<static method readdir : L<Sys::IO::Dirent|SPVM::Sys::IO::Dirent> ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
+
+Calls the L<readdir|https://linux.die.net/man/3/readdir> function and return its return value.
+
+Exceptions:
+
+$dirp must be defined. Otherwise an exception is thrown.
+
+If the readdir function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 rewinddir
+
+C<static method rewinddir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
+
+Calls the L<rewinddir|https://linux.die.net/man/3/rewinddir> function.
+
+Exceptions:
+
+$dirp must be defined. Otherwise an exception is thrown.
+
+=head2 telldir
+
+C<static method telldir : long ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
+
+Calls the L<telldir|https://linux.die.net/man/3/telldir> function and return its return value.
+
+Exceptions:
+
+$dirp must be defined. Otherwise an exception is thrown.
+
+If the telldir function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
+
+=head2 seekdir
+
+C<static method seekdir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>, $offset : long);>
+
+Calls the L<seekdir|https://linux.die.net/man/3/seekdir> function and return its return value.
+
+Exceptions:
+
+$dirp must be defined. Otherwise an exception is thrown.
+
+$offset must be less than or equal to 0.
+
 =head2 popen
 
 C<static method popen : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream> ($command : string, $type : string);>
 
 Calls the L<popen|https://linux.die.net/man/3/popen> function and returns its return value.
 
+The L<is_pipe|SPVM::Sys::IO::FileStream/"is_pipe"> field in the Sys::IO::FileStream class is set to 1.
+
 Exceptions:
 
 $command must be defined. Otherwise an exception is thrown.
@@ -697,6 +752,8 @@ $type must be defined. Otherwise an exception is thrown.
 
 If the popen function failed, an exception is thrown with C<eval_error_id> set to the basic type ID of the L<Error::System|SPVM::Error::System> class.
 
+The L<is_pipe|SPVM::Sys::IO::FileStream/"is_pipe"> field in the Sys::IO::FileStream class is set to 1.
+
 Exceptions:
 
 =head2 _popen
