@@ -8,7 +8,7 @@ SPVM::Sys::IO::Dirent - struct dirent in the C language
 
 =head1 Description
 
-The Sys::IO::Dirent class of L<SPVM> represents L<struct dirent|https://linux.die.net/man/3/readdir> in the C language.
+The Sys::IO::Dirent class in L<SPVM> represents L<struct dirent|https://linux.die.net/man/3/readdir> in the C language.
 
 =head1 Usage
   
@@ -27,7 +27,7 @@ The Sys::IO::Dirent class of L<SPVM> represents L<struct dirent|https://linux.di
 
 =head1 Details
 
-This class is a pointer class. The pointer of the instance is set to a C<struct dirent> object.
+This class is a pointer class. The pointer the instance has is set to a C<struct dirent> object.
 
 =head1 Class Methods
 
@@ -35,13 +35,13 @@ This class is a pointer class. The pointer of the instance is set to a C<struct
 
 C<method d_ino : int ();>
 
-Gets C<d_ino>.
+Returns C<d_ino>.
 
 =head2 d_reclen
 
 C<method d_reclen : int ();>
 
-Gets C<d_reclen>.
+Returns C<d_reclen>.
 
 =head2 d_name
 
@@ -53,13 +53,13 @@ Gets and copies C<d_name> and returns it.
 
 C<method d_off : long;>
 
-Gets C<d_off>.
+Returns C<d_off>.
 
 =head2 d_type
 
 C<method d_type : int ();>
 
-Gets C<d_type>.
+Returns C<d_type>.
 
 =head1 See Also
 
