@@ -6,15 +6,21 @@ package SPVM::Sys::Socket::In_addr;
 
 SPVM::Sys::Socket::In_addr - struct in_addr in the C language
 
+=head1 Description
+
+The Sys::Socket::In_addr class in L<SPVM> represents L<struct in_addr|https://linux.die.net/man/3/inet_network> in the C language.
+
 =head1 Usage
 
   use Sys::Socket::In_addr;
 
-=head1 Description
+=head1 Details
 
-C<Sys::Socket::In_addr> is the class for the C<struct in_addr> in the C language.
+This class is a pointer class. The pointer the instance has is set to a L<struct in_addr|https://linux.die.net/man/3/inet_network> object.
 
-This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
+=head1 Inheritance
+
+L<Sys::Socket::In_addr_base|SPVM::Sys::Socket::In_addr_base>
 
 =head1 Class Methods
 
@@ -22,7 +28,7 @@ This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
 
 C<static method new : L<Sys::Socket::In_addr|SPVM::Sys::Socket::In_addr> ();>
 
-Creates a new C<Sys::Socket::In_addr> object.
+Creates a new L<Sys::Socket::In_addr|SPVM::Sys::Socket::In_addr> object.
 
 =head1 Instance Methods
 
@@ -36,11 +42,11 @@ The destructor.
 
 C<method s_addr : int ();>
 
-Gets C<s_addr>.
+Returns C<s_addr>.
 
 =head2 set_s_addr
 
-C<method set_s_addr : void ();>
+C<method set_s_addr : void ($s_addr : int)>
 
 Sets C<s_addr>.
 
