@@ -3,4 +3,4 @@ use warnings;
 
 my ($message) = @ARGV;
 
-warn "[Test Output]execv:Hello $message";
+print "Hello $message";
